#!/bin/sh

# Script used as entrypoint for KC and VDP environments.

set -ex -o pipefail

ENV=${ENV:-localdev}

# Init Java options - ORG_JAVA_OPTS will keep the original value when the script was started for the first time
JAVA_OPTS+="${ORG_JAVA_OPTS:=${JAVA_OPTS:- }}"
export $ORG_JAVA_OPTS

JAVA_OPTS+=" -showversion \
-XX:+PrintFlagsFinal \
-XX:+PrintCommandLineFlags \
-XX:+PrintStringTableStatistics \
-XX:ErrorFile=/tmp/error_java_access_%p.log \
-Xlog:gc*:/tmp/access.txt:time,level,tags:filesize=50M,filecount=1 \
-Xms${JVM_XMS:-768m} -Xmx${JVM_XMX:-1536m} \
-Xss384k \
-XX:MaxJavaStackTraceDepth=0 \
-XX:SurvivorRatio=8 \
-XX:TargetSurvivorRatio=90 \
-XX:MaxTenuringThreshold=15 \
-XX:ParallelGCThreads=4 \
-XX:+OptimizeStringConcat \
-XX:MaxMetaspaceSize=256m"

# Configure Datasource
DATASOURCE_URI=""
if [ -n "$DATASOURCE_URL" ]; then
  DATASOURCE_URI=$DATASOURCE_URL
fi

if [ -z "$DATASOURCE_URI" -a -n "$PGHOST" -a -n "$PGDATABASE" ]; then
  DATASOURCE_URI="jdbc:postgresql://$PGHOST"
  if [ -n "$PGPORT" ]; then
    DATASOURCE_URI+=":$PGPORT"
  fi
  DATASOURCE_URI+="/$PGDATABASE"
fi

if [ -n "$DATASOURCE_URI" ]; then
  JAVA_OPTS+=" -Dspring.datasource.url=$DATASOURCE_URI"
  if [ -n "$DATASOURCE_PARAMS" ]; then
   JAVA_OPTS+="?$DATASOURCE_PARAMS"
  fi
fi

if [ -n "$DATASOURCE_USER" ]; then
  JAVA_OPTS+=" -Dspring.datasource.username=$DATASOURCE_USER"
fi

if [ -n "$DATASOURCE_PASS" ]; then
  JAVA_OPTS+=" -Dspring.datasource.password=$DATASOURCE_PASS"
fi

if [ -n "$EXT_JAVA_OPTS" ]; then
  echo "External java options: $EXT_JAVA_OPTS"
  JAVA_OPTS+=" $EXT_JAVA_OPTS"
fi

# Append any profiles that are configured
if [ -n "$SPRING_PROFILES_ACTIVE" ]; then
  JAVA_OPTS+=" -Dspring.profiles.active=$SPRING_PROFILES_ACTIVE"
fi

echo "JAVA_OPTS: $JAVA_OPTS"

MULTI_ENVS=()
IFS=',' read -ra MULTI_ENVS <<< $(echo "${ENV}")

if [ -n "${MULTIENV_CONNECTORS}" ]; then
	API_KEY=""
	CONNECTOR_ID=""
	CONN_SEC_ENVS=$(echo "$MULTIENV_CONNECTORS" | jq -Mr 'keys_unsorted[]')
	for env in ${MULTI_ENVS[@]}; do
		if [ `echo "${CONN_SEC_ENVS[@]}" | grep $env` ]; then
			API_KEY="${API_KEY},$(echo ${MULTIENV_CONNECTORS} | jq -Mr '.'"$env"'."api-key"' )"
			CONNECTOR_ID="${CONNECTOR_ID},$(echo ${MULTIENV_CONNECTORS} | jq -Mr '.'"$env"'."connector-id"' )"
		fi
	done
	API_KEY=${API_KEY:1}
	CONNECTOR_ID=${CONNECTOR_ID:1}
fi

java ${JAVA_OPTS} -cp ${BCFIPS_JARS:+"$BCFIPS_JARS":}:* -jar /app/access.jar "$@" &
PID=$!

EXITCODE=0
wait "$PID" || EXITCODE=$?
echo "Java process exited with $EXITCODE"
exit "$EXITCODE"
